@@ -53,7 +53,7 @@ gg_step <- function(data = NULL,
                     x_labels = NULL,
                     x_limits = NULL,
                     x_oob = scales::oob_keep,
-                    x_position = "bottom",
+                    x_orientation = NULL, x_position = "bottom",
                     x_label = NULL,
                     x_transform = NULL,
                     y_breaks = NULL,
@@ -62,7 +62,7 @@ gg_step <- function(data = NULL,
                     y_labels = NULL,
                     y_limits = NULL,
                     y_oob = scales::oob_keep,
-                    y_position = "left",
+                    y_orientation = NULL, y_position = "left",
                     y_label = NULL,
                     y_transform = NULL,
                     col_breaks = NULL,
@@ -124,7 +124,7 @@ gg_step <- function(data = NULL,
     x_labels = x_labels,
     x_limits = x_limits,
     x_oob = x_oob,
-    x_position = x_position,
+    x_orientation = x_orientation, x_position = x_position,
     x_label = x_label,
     x_transform = x_transform,
     y_breaks = y_breaks,
@@ -133,7 +133,7 @@ gg_step <- function(data = NULL,
     y_labels = y_labels,
     y_limits = y_limits,
     y_oob = y_oob,
-    y_position = y_position,
+    y_orientation = y_orientation, y_position = y_position,
     y_label = y_label,
     y_transform = y_transform,
     col_breaks = col_breaks,
